.. image:: ./_static/github-social-card.png

.. include:: badges.rst

----

.. include:: explanation.rst

----

Documentation
=============

.. toctree::
   :maxdepth: 1
   :caption: Content

   install
   quickstart
   sampling
   lymph
   license

Index & search
--------------

*  :ref:`genindex`
*  :ref:`search`

----

.. include:: refs.rst